#
# spec file for package python-metaextract
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-metaextract
Version:        1.0.9
Release:        3.3
Summary:        Module to collect metadata for Python modules
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            http://github.com/toabctl/metaextract
Source:         https://github.com/toabctl/metaextract/archive/%{version}.tar.gz
# PATCH-FIX-UPSTREAM tests-tests_require.patch gh#toabctl/metaextract#20 mcepl@suse.com
# Fix failing tests
Patch0:         tests-tests_require.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# Needed even though no tests are present
BuildRequires:  %{python_module pbr}
BuildRequires:  %{python_module pytest}
Requires:       python-setuptools
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Requires(post): update-alternatives
Requires(postun): update-alternatives
%python_subpackages

%description
metaextract is a tool to collect metadata about a python module. For
example, it can determine and collect the dependencies of a sdist
tarball that was retrieved from the Python Package Index.

The tool was first developed in py2pack but is now its own module.

%prep
%autosetup -p1 -n metaextract-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%python_clone -a %{buildroot}%{_bindir}/metaextract

%post
%python_install_alternative metaextract

%postun
%python_uninstall_alternative metaextract

%check
%pytest

%files %{python_files}
%defattr(-,root,root,-)
%doc README.rst
%license LICENSE
%python_alternative %{_bindir}/metaextract
%{python_sitelib}/metaextract
%{python_sitelib}/metaextract-%{version}*-info

%changelog
* Wed Oct  2 2024 Matej Cepl <mcepl@cepl.eu>
- Add tests-tests_require.patch fixing broken tests
  (gh#toabctl/metaextract#20).
* Wed Jun 21 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Fri Oct 14 2022 Daniel Garcia <daniel.garcia@suse.com>
- Change preun to postun for update alternatives
- Remove not needed setup.py patch
- Change shared files python-sitelib glob to package
- Update source package
* Thu Oct 13 2022 Thomas Bechtold <thomasbechtold@jpberlin.de>
- Update to Version 1.0.9:
  * ci: drop python 3.7, add python 3.10
  * Add initial support for packages without setup.py
  * Update badge given that github actions are now used
* Thu Sep 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to Version 1.0.8:
  * Merge pull request #15 from toabctl/gh-instead-of-travis
  * Move from Travis CI to github actions
  * Merge pull request #14 from toabctl/drop-pytest-runner
  * Post release version bump to 1.0.8
  * setup.py: drop setup_requires including setuptools and pytest-runner
  * Merge pull request #12 from jayvdb/json_dumps_default
  * Use default json encoder 'str'
* Wed Dec  8 2021 pgajdos@suse.com
- do not require pytest-runner for build, it is not needed
* Sun Mar 29 2020 Thomas Bechtold <tbechtold@suse.com>
- update to 1.0.7:
  * Use default json encoder 'str'
* Tue Aug 27 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary. Trim history from description.
  Fix wrong "it's".
* Thu Aug  8 2019 Thomas Bechtold <tbechtold@suse.com>
- Capitalize summary to make rpmlint happy
* Thu Aug  8 2019 Thomas Bechtold <tbechtold@suse.com>
- update to 1.0.6:
  * Switch to python 3.7
  * travis: Use py36 for pep8 tox env
  * Fix tests when using pytest >= 5
* Fri Jun 21 2019 pgajdos@suse.com
- run the testsuite in %%check
* Thu Mar  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix fdupes call
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri Nov  9 2018 Thomas Bechtold <tbechtold@suse.com>
- update to 1.0.5:
  * Add more key from setup.py to output
  * tests: Only check expected key/value pairs
  * Post release version bump to 1.0.5
* Sat Jun  9 2018 tbechtold@suse.com
- update to 1.0.4:
  * Convert sets used in entry_points to lists
  * Fix unittests
  * Post release version bump to 1.0.4
- use %%license macro
* Mon Sep 18 2017 tbechtold@suse.com
- update to 1.0.3:
  * Release 1.0.3
  * Test python 3.6 instead of 3.5
  * Fix json serialization for dict_items on py3 (#4)
* Thu Apr 27 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Mon Apr 24 2017 tbechtold@suse.com
  update to version 1.0.2
  * Fix entrypoint typo 'metaextact'
* Tue Feb 28 2017 tbechtold@suse.com
  update to version 1.0.0
  * Allow to specify the used python interpreter
  * Fix utils import in python3 case
  * Post release version bump to 1.0.0
* Tue Feb 28 2017 tbechtold@suse.com
  update to version 0.0.9
  * Improve tests with extras_require
  * Fix documentation link in README
  * Post release version bump to 0.0.9
  * Support "python_requires"
  * Use same version for doc and sdist
  * Add doc badge to README
  * Use already used python interpreter
  * Post release version bump to 0.0.8
  * Use Sphinx to build documentation
* Mon Aug 29 2016 tbechtold@suse.com
  update to version 0.0.7
  * Sort some of the data keys
  * Post release version bump to 0.0.7
  * Sort json dump by key
* Sun Aug 28 2016 tbechtold@suse.com
- Initial packaging (version 0.0.6)
